@@ -25,9 +25,16 @@ as.module.default <- function(x, ...) {
   as.list(x)
 }
 
+#' @export
+as.module.function <- function(x, ...) {
+  x
+}
+
+
 #' @export
 #' @rdname modulecoerce
-as.module.character <- function(x, topEncl = baseenv(), reInit = TRUE, ...) {
+as.module.character <- function(x, topEncl = baseenv(), reInit = TRUE, ...,
+                                envir = parent.frame()) {
   stopifnot(length(x) == 1)
 
   dirAsModule <- function(x, topEncl, ...) {
@@ -38,18 +45,26 @@ as.module.character <- function(x, topEncl = baseenv(), reInit = TRUE, ...) {
   }
 
   fileAsModule <- function(x, topEncl, ...) {
-    do.call(module, list(parse(x, ...), topEncl))
+    do.call(module, list(parse(x, ...), topEncl, envir))
   }
 
+  urlAsModule <- function(x, topEncl, ...) {
+    download.file(x, fileName <- tempfile(fileext = ".R"))
+    fileAsModule(fileName, topEncl, ...)
+  }
+
+  is.url <- function(x) grepl("^(https?|ftp)://", x)
+
   if (dir.exists(x)) dirAsModule(x, topEncl, ...)
   else if (file.exists(x)) fileAsModule(x, topEncl, ...)
+  else if (is.url(x)) urlAsModule(x, topEncl, ...)
   else stop("Can`t find ", x)
-  
+
 }
 
 #' @export
 #' @rdname modulecoerce
 as.module.module <- function(x, reInit = TRUE, ...) {
-  if (reInit) ModuleConst(attr(x, "expr"), attr(x, "topEncl"))
+  if (reInit) ModuleConst(attr(x, "expr"), attr(x, "topEncl"), attr(x, "topenv"))
   else x
 }
